summaryrefslogtreecommitdiffstats
path: root/bin
diff options
context:
space:
mode:
Diffstat (limited to 'bin')
-rwxr-xr-xbin/reproducible_html_live_status.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/bin/reproducible_html_live_status.py b/bin/reproducible_html_live_status.py
index e1a3d8c2..685fb97b 100755
--- a/bin/reproducible_html_live_status.py
+++ b/bin/reproducible_html_live_status.py
@@ -82,8 +82,8 @@ def generate_live_status_table(arch):
counter = 0
for row in rows:
counter += 1
- # the numbers 17 and 9 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
- if ( arch == 'amd64' and counter == 17 ) or ( arch == 'armhf' and counter == 9 ):
+ # the numbers 33 and 9 should really be derived from /var/lib/jenkins/jobs/reproducible_builder_${arch}_* instead of being hard-coded here...
+ if ( arch == 'amd64' and counter == 33 ) or ( arch == 'armhf' and counter == 9 ):
html += '<tr><td colspan="10">There are more builds marked as currently building in the database than there are ' + arch + ' build jobs. This does not compute, please investigate and fix the cause.</td></tr>'
suite = row[1]
arch = row[2]